==> json-joy-2.7.0.tgz: package/esm/binary-rx/BinaryRxClient.js <==
import { NotificationMessage, SubscribeMessage, DataMessage, CompleteMessage, UnsubscribeMessage, ErrorMessage } from './messages';
import { Observable } from 'rxjs';
import { TimedQueue } from '../json-rx/TimedQueue';
import { decodeCompleteMessages, Encoder } from './codec';
export class BinaryRxClient {
    constructor({ send, bufferSize = 100, bufferTime = 10 }) {
        this.id = 1;
        this.encoder = new Encoder();
        this.observers = new Map();
        this.buffer = new TimedQueue();
        this.buffer.itemLimit = bufferSize;
        this.buffer.timeLimit = bufferTime;
        this.buffer.onFlush = (messages) => {
            send(this.encoder.encode(messages));
        };
    }
    sendSubscribe(id, method, data) {
        const message = new SubscribeMessage(id, method, data);
        this.buffer.push(message);
    }
    sendUnsubscribe(id) {
        this.buffer.push(new UnsubscribeMessage(id));
    }
    onData(message) {
        const { id, data } = message;
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.observer.next(data);
    }
    onComplete(message) {
        const { id, data } = message;
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        if (data && data.byteLength)
            observer.observer.next(data);
        observer.observer.complete();
    }
    onError(message) {
        const { id, data } = message;
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        observer.observer.error(data);
    }
    onArray(arr) {
        const messages = decodeCompleteMessages(arr, 0);
        this.onMessages(messages);
    }
    onMessages(messages) {
        const length = messages.length;
        for (let i = 0; i < length; i++) {
            const message = messages[i];
            if (message instanceof CompleteMessage)
                this.onComplete(message);
            else if (message instanceof DataMessage)
                this.onData(message);
            else if (message instanceof ErrorMessage)
                this.onError(message);
        }
    }
    call(method, data) {
        const id = this.id++;
        if (this.id >= 0xFFFF)
            this.id = 0;
        if (this.observers.has(id))
            return this.call(method, data);
        const observable = new Observable((observer) => {
            const entry = { observer };
            this.observers.set(id, entry);
            return () => {
                this.observers.delete(id);
                if (!entry.completed)
                    this.sendUnsubscribe(id);
            };
        });
        this.sendSubscribe(id, method, data);
        return observable;
    }
    notify(method, data) {
        const message = new NotificationMessage(method, data);
        this.buffer.push(message);
    }
    stop() {
        this.buffer.onFlush = (message) => { };
        for (const { observer } of this.observers.values())
            observer.complete();
    }
}

==> json-joy-2.8.0.tgz: package/esm/binary-rx/BinaryRxClient.js <==
import { NotificationMessage, SubscribeMessage, DataMessage, CompleteMessage, UnsubscribeMessage, ErrorMessage } from './messages';
import { Observable } from 'rxjs';
import { TimedQueue } from '../json-rx/TimedQueue';
import { decodeFullMessages, Encoder } from './codec';
export class BinaryRxClient {
    constructor({ send, bufferSize = 100, bufferTime = 10 }) {
        this.id = 1;
        this.encoder = new Encoder();
        this.observers = new Map();
        this.buffer = new TimedQueue();
        this.buffer.itemLimit = bufferSize;
        this.buffer.timeLimit = bufferTime;
        this.buffer.onFlush = (messages) => {
            send(this.encoder.encode(messages));
        };
    }
    sendSubscribe(id, method, data) {
        const message = new SubscribeMessage(id, method, data);
        this.buffer.push(message);
    }
    sendUnsubscribe(id) {
        this.buffer.push(new UnsubscribeMessage(id));
    }
    onData(message) {
        const { id, data } = message;
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.observer.next(data);
    }
    onComplete(message) {
        const { id, data } = message;
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        if (data && data.byteLength)
            observer.observer.next(data);
        observer.observer.complete();
    }
    onError(message) {
        const { id, data } = message;
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        observer.observer.error(data);
    }
    onArray(arr) {
        const messages = decodeFullMessages(arr, 0);
        this.onMessages(messages);
    }
    onMessages(messages) {
        const length = messages.length;
        for (let i = 0; i < length; i++) {
            const message = messages[i];
            if (message instanceof CompleteMessage)
                this.onComplete(message);
            else if (message instanceof DataMessage)
                this.onData(message);
            else if (message instanceof ErrorMessage)
                this.onError(message);
        }
    }
    call(method, data) {
        const id = this.id++;
        if (this.id >= 0xFFFF)
            this.id = 0;
        if (this.observers.has(id))
            return this.call(method, data);
        const observable = new Observable((observer) => {
            const entry = { observer };
            this.observers.set(id, entry);
            return () => {
                this.observers.delete(id);
                if (!entry.completed)
                    this.sendUnsubscribe(id);
            };
        });
        this.sendSubscribe(id, method, data);
        return observable;
    }
    notify(method, data) {
        const message = new NotificationMessage(method, data);
        this.buffer.push(message);
    }
    stop() {
        this.buffer.onFlush = (message) => { };
        for (const { observer } of this.observers.values())
            observer.complete();
    }
}
